@@ -37,12 +37,7 @@
 #include <stdio.h>
 #include <string.h>
 
-#if !defined(LITTLE_ENDIAN) && defined(__LITTLE_ENDIAN)
-#define LITTLE_ENDIAN __LITTLE_ENDIAN
-#endif
-#if !defined(BIG_ENDIAN) && defined(__BIG_ENDIAN)
-#define BIG_ENDIAN __BIG_ENDIAN
-#endif
+#include "config.h"
 
 #ifndef Bytes_val
 #define Bytes_val String_val
@@ -198,13 +193,10 @@ CAMLprim value ocaml_lame_encode_buffer_interleaved(value l, value _buf,
   memcpy(inbuf, String_val(_buf), inbuf_len);
 
   caml_release_runtime_system();
-#if BYTE_ORDER == LITTLE_ENDIAN
-#elif BYTE_ORDER == BIG_ENDIAN
+#ifdef BIGENDIAN
   int i;
   for (i = 0; i < inbuf_len / 2; i++)
     inbuf[i] = bswap_16(inbuf[i]);
-#else
-#error "Indians shall be either little or big, no other choice here."
 #endif
   ans = lame_encode_buffer_interleaved(lgf, inbuf, samples, outbuf, sizeof(outbuf));
   caml_acquire_runtime_system();
@@ -263,6 +255,8 @@ CAMLprim value ocaml_lame_encode_buffer_float_ba(value l, value _bufl,
   lame_global_flags *lgf = Lame_val(l);
   struct caml_ba_array *bal = Caml_ba_array_val(_bufl);
   struct caml_ba_array *bar = Caml_ba_array_val(_bufr);
+  const float *bufl = bal->data;
+  const float *bufr = bar->data;
   int samples = bal->dim[0];
   if (bar->dim[0] != samples)
     caml_failwith("Invalid argument: buffers must be of same length");
@@ -272,7 +266,7 @@ CAMLprim value ocaml_lame_encode_buffer_float_ba(value l, value _bufl,
   unsigned char outbuf[LAME_MAXMP3BUFFER];
   int ans;
 
-  ans = lame_encode_buffer_float(lgf, bal->data, bar->data, samples, outbuf,
+  ans = lame_encode_buffer_float(lgf, bufl, bufr, samples, outbuf,
                                  sizeof(outbuf));
 
   caml_acquire_runtime_system();
